from setuptools import setup, find_packages

setup(
    name="PythonOS",
    version="0.1.4",
    description="A simple OS package that can be used to build a Python OS.",
    long_description="A simple OS package that can be used to build a Python OS simply using our package. \n Credit to Eric for creating and caring for this package.",
    author="Eric",
    author_email="email@devwatch.epizy.com",
    packages=find_packages(),
    license="MIT",
    keywords=["PythonOS"],
    requires=[]
)